@@ -701,17 +701,8 @@ gplugin_manager_real_refresh(GPluginManager *manager)
 							errors++;
 
 							g_error_free(error);
-						} else {
-							gplugin_plugin_set_state(
-								plugin,
-								GPLUGIN_PLUGIN_STATE_LOADED);
 						}
 					} else {
-						/* finally set the plugin state queried */
-						gplugin_plugin_set_state(
-							plugin,
-							GPLUGIN_PLUGIN_STATE_QUERIED);
-
 						/* if errors is greater than 0 set
 						 * manager->refresh_needed to TRUE.
 						 */
@@ -966,8 +957,9 @@ gplugin_manager_real_load_plugin(
 	g_return_val_if_fail(GPLUGIN_IS_PLUGIN(plugin), FALSE);
 
 	/* if the plugin is already loaded there's nothing for us to do */
-	if(gplugin_plugin_get_state(plugin) == GPLUGIN_PLUGIN_STATE_LOADED)
+	if(gplugin_plugin_get_state(plugin) == GPLUGIN_PLUGIN_STATE_LOADED) {
 		return TRUE;
+	}
 
 	/* now try to get the plugin info from the plugin */
 	info = gplugin_plugin_get_info(plugin);
@@ -1029,27 +1021,8 @@ gplugin_manager_real_load_plugin(
 
 	ret = gplugin_loader_load_plugin(loader, plugin, &error);
 	if(ret) {
-		/* If the plugin successfully loaded but returned an error, ignore the
-		 * error.
-		 */
-		g_clear_error(&error);
-
-		/* Likewise, make sure the plugin's error is set to NULL. */
-		g_object_set(G_OBJECT(plugin), "error", NULL, NULL);
-
-		gplugin_plugin_set_state(plugin, GPLUGIN_PLUGIN_STATE_LOADED);
 		g_signal_emit(manager, signals[SIG_LOADED], 0, plugin);
 	} else {
-		/* Set the error on the plugin as well.  This  has to be before we
-		 * propagate the error, because error is invalidate at that point.
-		 */
-		g_object_set(G_OBJECT(plugin), "error", error, NULL);
-
-		/* Set the state after the error is set, because people might connect
-		 * to the notify signal on the state property.
-		 */
-		gplugin_plugin_set_state(plugin, GPLUGIN_PLUGIN_STATE_LOAD_FAILED);
-
 		g_signal_emit(manager, signals[SIG_LOAD_FAILED], 0, plugin);
 
 		g_propagate_error(ret_error, error);
@@ -1070,8 +1043,9 @@ gplugin_manager_real_unload_plugin(
 
 	g_return_val_if_fail(GPLUGIN_IS_PLUGIN(plugin), FALSE);
 
-	if(gplugin_plugin_get_state(plugin) != GPLUGIN_PLUGIN_STATE_LOADED)
+	if(gplugin_plugin_get_state(plugin) != GPLUGIN_PLUGIN_STATE_LOADED) {
 		return TRUE;
+	}
 
 	loader = gplugin_plugin_get_loader(plugin);
 	if(!GPLUGIN_IS_LOADER(loader)) {
@@ -1091,32 +1065,15 @@ gplugin_manager_real_unload_plugin(
 
 		g_propagate_error(ret_error, error);
 
+		gplugin_plugin_set_state(plugin, GPLUGIN_PLUGIN_STATE_LOAD_FAILED);
+
 		return ret;
 	}
 
 	ret = gplugin_loader_unload_plugin(loader, plugin, &error);
 	if(ret) {
-		/* If the plugin successfully loaded but returned an error, ignore the
-		 * error.
-		 */
-		g_clear_error(&error);
-
-		/* Like, make sure the plugin's error is set to NULL. */
-		g_object_set(G_OBJECT(plugin), "error", NULL, NULL);
-
-		gplugin_plugin_set_state(plugin, GPLUGIN_PLUGIN_STATE_QUERIED);
 		g_signal_emit(manager, signals[SIG_UNLOADED], 0, plugin);
 	} else {
-		/* Set the error on the plugin as well.  This  has to be before we
-		 * propagate the error, because error is invalidate at that point.
-		 */
-		g_object_set(G_OBJECT(plugin), "error", error, NULL);
-
-		/* Set the state after the error is set, because people might connect
-		 * to the notify signal on the state property.
-		 */
-		gplugin_plugin_set_state(plugin, GPLUGIN_PLUGIN_STATE_UNLOAD_FAILED);
-
 		g_signal_emit(manager, signals[SIG_UNLOAD_FAILED], 0, plugin);
 
 		g_propagate_error(ret_error, error);
