@@ -16,8 +16,10 @@
 use strict;
 
 use Glib::Object::Introspection;
+use Scalar::Util qw(blessed);
 
-Glib::Object::Introspection->setup(basename => "GPlugin", version => "1.0", package=> "GPlugin");
+Glib::Object::Introspection->setup(basename => "GPlugin", version => "1.0",
+                                   package => "GPlugin");
 
 sub gplugin_query {
 	return GPlugin::PluginInfo->new(
@@ -35,9 +37,21 @@ sub gplugin_query {
 }
 
 sub gplugin_load {
+	my $plugin = shift;
+
+	if(!defined($plugin) or (blessed($plugin) and !$plugin->isa("GPlugin::Plugin"))) {
+		die("plugin is not a GPlugin::Plugin");
+	}
+
 	return 0;
 }
 
 sub gplugin_unload {
+	my $plugin = shift;
+
+	if(!defined($plugin) or (blessed($plugin) and !$plugin->isa("GPlugin::Plugin"))) {
+		die("plugin is not a GPlugin::Plugin");
+	}
+
 	return 0;
 }
