@@ -17,20 +17,21 @@ use strict;
 
 use Glib::Object::Introspection;
 
-Glib::Object::Introspection->setup(basename => "GPlugin", version => "1.0", package=> "GPlugin");
+Glib::Object::Introspection->setup(basename => "GPlugin", version => "1.0",
+                                   package => "GPlugin");
 
-sub gplugin_query() {
+sub gplugin_query {
 	return GPlugin::PluginInfo->new(
 		id => "gplugin/perl5-load-exception",
 	);
 }
 
-sub gplugin_load() {
+sub gplugin_load {
 	die("you be dead");
 
 	return 0;
 }
 
-sub gplugin_unload() {
+sub gplugin_unload {
 	return 0;
 }
